@@ -1,37 +1,36 @@
+# frozen_string_literal: true
+
 module Octokit
   class Client
-
     # Methods for the Repositories API
     #
     # @see https://developer.github.com/v3/repos/
     module Repositories
-
       # Check if a repository exists
       #
       # @see https://developer.github.com/v3/repos/#get
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
-      # @return [Sawyer::Resource] if a repository exists, false otherwise
+      # @return [Boolean]
       def repository?(repo, options = {})
         !!repository(repo, options)
-      rescue Octokit::InvalidRepository
-        false
-      rescue Octokit::NotFound
+      rescue Octokit::InvalidRepository, Octokit::NotFound
         false
       end
 
       # Get a single repository
       #
       # @see https://developer.github.com/v3/repos/#get
+      # @see https://developer.github.com/v3/licenses/#get-a-repositorys-license
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
       # @return [Sawyer::Resource] Repository information
       def repository(repo, options = {})
         get Repository.path(repo), options
       end
-      alias :repo :repository
+      alias repo repository
 
       # Edit a repository
       #
-      # @see https://developer.github.com/v3/repos/#edit
+      # @see https://developer.github.com/v3/repos/#update-a-repository
       # @param repo [String, Hash, Repository] A GitHub repository
       # @param options [Hash] Repository information to update
       # @option options [String] :name Name of the repo
@@ -40,6 +39,7 @@ module Octokit
       # @option options [String] :private `true` makes the repository private, and `false` makes it public.
       # @option options [String] :has_issues `true` enables issues for this repo, `false` disables issues.
       # @option options [String] :has_wiki `true` enables wiki for this repo, `false` disables wiki.
+      # @option options [Boolean] :is_template `true` makes the repository a template, `false` makes it not a template.
       # @option options [String] :has_downloads `true` enables downloads for this repo, `false` disables downloads.
       # @option options [String] :default_branch Update the default branch for this repository.
       # @return [Sawyer::Resource] Repository information
@@ -48,9 +48,9 @@ module Octokit
         options[:name] ||= repo.name
         patch "repos/#{repo}", options
       end
-      alias :edit :edit_repository
-      alias :update_repository :edit_repository
-      alias :update :edit_repository
+      alias edit edit_repository
+      alias update_repository edit_repository
+      alias update edit_repository
 
       # List user repositories
       #
@@ -66,12 +66,12 @@ module Octokit
       # @param user [Integer, String] Optional GitHub user login or id for which
       #   to list repos.
       # @return [Array<Sawyer::Resource>] List of repositories
-      def repositories(user=nil, options = {})
+      def repositories(user = nil, options = {})
         paginate "#{User.path user}/repos", options
       end
-      alias :list_repositories :repositories
-      alias :list_repos :repositories
-      alias :repos :repositories
+      alias list_repositories repositories
+      alias list_repos repositories
+      alias repos repositories
 
       # List all repositories
       #
@@ -143,6 +143,7 @@ module Octokit
       # @option options [String] :private `true` makes the repository private, and `false` makes it public.
       # @option options [String] :has_issues `true` enables issues for this repo, `false` disables issues.
       # @option options [String] :has_wiki `true` enables wiki for this repo, `false` disables wiki.
+      # @option options [Boolean] :is_template `true` makes this repo available as a template repository, `false` to prevent it.
       # @option options [String] :has_downloads `true` enables downloads for this repo, `false` disables downloads.
       # @option options [String] :organization Short name for the org under which to create the repo.
       # @option options [Integer] :team_id The id of the team that will be granted access to this repository. This is only valid when creating a repo in an organization.
@@ -151,17 +152,18 @@ module Octokit
       # @return [Sawyer::Resource] Repository info for the new repository
       # @see https://developer.github.com/v3/repos/#create
       def create_repository(name, options = {})
-        organization = options.delete :organization
-        options.merge! :name => name
+        opts = options.dup
+        organization = opts.delete :organization
+        opts.merge! name: name
 
         if organization.nil?
-          post 'user/repos', options
+          post 'user/repos', opts
         else
-          post "#{Organization.path organization}/repos", options
+          post "#{Organization.path organization}/repos", opts
         end
       end
-      alias :create_repo :create_repository
-      alias :create :create_repository
+      alias create_repo create_repository
+      alias create create_repository
 
       # Delete repository
       #
@@ -173,7 +175,36 @@ module Octokit
       def delete_repository(repo, options = {})
         boolean_from_response :delete, Repository.path(repo), options
       end
-      alias :delete_repo :delete_repository
+      alias delete_repo delete_repository
+
+      # Transfer repository
+      #
+      # Transfer a repository owned by your organization
+      #
+      # @see https://developer.github.com/v3/repos/#transfer-a-repository
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository
+      # @param new_owner [String] The username or organization name the repository will be transferred to.
+      # @param options [Array<Integer>] :team_ids ID of the team or teams to add to the repository. Teams can only be added to organization-owned repositories.
+      # @return [Sawyer::Resource] Repository info for the transferred repository
+      def transfer_repository(repo, new_owner, options = {})
+        post "#{Repository.path repo}/transfer", options.merge({ new_owner: new_owner })
+      end
+      alias transfer_repo transfer_repository
+
+      # Create a repository for a user or organization generated from a template repository
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub template repository
+      # @param name [String] Name of the new repo
+      # @option options [String] :owner Organization or user who the new repository will belong to.
+      # @option options [String] :description Description of the repo
+      # @option options [String] :private `true` makes the repository private, and `false` makes it public.
+      # @option options [Boolean] :include_all_branches `true` copies all branches from the template repository, `false` (default) makes it only copy the master branch.
+      # @return [Sawyer::Resource] Repository info for the new repository
+      def create_repository_from_template(repo, name, options = {})
+        options.merge! name: name
+        post "#{Repository.path repo}/generate", options
+      end
+      alias create_repo_from_template create_repository_from_template
 
       # Hide a public repository
       #
@@ -181,7 +212,7 @@ module Octokit
       # @return [Sawyer::Resource] Updated repository info
       def set_private(repo, options = {})
         # GitHub Api for setting private updated to use private attr, rather than public
-        update_repository repo, options.merge({ :private => true })
+        update_repository repo, options.merge({ private: true })
       end
 
       # Unhide a private repository
@@ -190,7 +221,7 @@ module Octokit
       # @return [Sawyer::Resource] Updated repository info
       def set_public(repo, options = {})
         # GitHub Api for setting private updated to use private attr, rather than public
-        update_repository repo, options.merge({ :private => false })
+        update_repository repo, options.merge({ private: false })
       end
 
       # Get deploy keys on a repo
@@ -199,7 +230,7 @@ module Octokit
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
       # @return [Array<Sawyer::Resource>] Array of hashes representing deploy keys.
-      # @see https://developer.github.com/v3/repos/keys/#list
+      # @see https://developer.github.com/v3/repos/keys/#list-deploy-keys
       # @example
       #   @client.deploy_keys('octokit/octokit.rb')
       # @example
@@ -207,17 +238,17 @@ module Octokit
       def deploy_keys(repo, options = {})
         paginate "#{Repository.path repo}/keys", options
       end
-      alias :list_deploy_keys :deploy_keys
+      alias list_deploy_keys deploy_keys
 
       # Get a single deploy key for a repo
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param id [Integer] Deploy key ID.
       # @return [Sawyer::Resource] Deploy key.
-      # @see https://developer.github.com/v3/repos/keys/#get
+      # @see https://developer.github.com/v3/repos/keys/#get-a-deploy-key
       # @example
       #   @client.deploy_key('octokit/octokit.rb', 8675309)
-      def deploy_key(repo, id, options={})
+      def deploy_key(repo, id, options = {})
         get "#{Repository.path repo}/keys/#{id}", options
       end
 
@@ -229,11 +260,11 @@ module Octokit
       # @param title [String] Title reference for the deploy key.
       # @param key [String] Public key.
       # @return [Sawyer::Resource] Hash representing newly added key.
-      # @see https://developer.github.com/v3/repos/keys/#create
+      # @see https://developer.github.com/v3/repos/keys/#add-a-new-deploy-key
       # @example
       #    @client.add_deploy_key('octokit/octokit.rb', 'Staging server', 'ssh-rsa AAA...')
       def add_deploy_key(repo, title, key, options = {})
-        post "#{Repository.path repo}/keys", options.merge(:title => title, :key => key)
+        post "#{Repository.path repo}/keys", options.merge(title: title, key: key)
       end
 
       # Edit a deploy key
@@ -246,7 +277,7 @@ module Octokit
       # @return [Sawyer::Resource] Updated deploy key.
       # @deprecated This method is no longer supported in the API
       # @see https://developer.github.com/changes/2014-02-24-finer-grained-scopes-for-ssh-keys/
-      # @see https://developer.github.com/v3/repos/keys/#edit
+      # @see https://developer.github.com/v3/repos/keys/#edit-a-deploy-key
       # @example Update the key for a deploy key.
       #   @client.edit_deploy_key('octokit/octokit.rb', 8675309, :key => 'ssh-rsa BBB...')
       # @example
@@ -254,7 +285,7 @@ module Octokit
       def edit_deploy_key(repo, id, options)
         patch "#{Repository.path repo}/keys/#{id}", options
       end
-      alias :update_deploy_key :edit_deploy_key
+      alias update_deploy_key edit_deploy_key
 
       # Remove deploy key from a repo
       #
@@ -263,7 +294,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param id [Integer] Id of the deploy key to remove.
       # @return [Boolean] True if key removed, false otherwise.
-      # @see https://developer.github.com/v3/repos/keys/#delete
+      # @see https://developer.github.com/v3/repos/keys/#remove-a-deploy-key
       # @example
       #   @client.remove_deploy_key('octokit/octokit.rb', 100000)
       def remove_deploy_key(repo, id, options = {})
@@ -275,8 +306,11 @@ module Octokit
       # Requires authenticated client for private repos.
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @option options [String] :affiliation Filters the return array by affiliation.
+      #   Can be one of: <tt>outside</tt>, <tt>direct</tt>, or <tt>all</tt>.
+      #   If not specified, defaults to <tt>all</tt>
       # @return [Array<Sawyer::Resource>] Array of hashes representing collaborating users.
-      # @see https://developer.github.com/v3/repos/collaborators/#list
+      # @see https://developer.github.com/v3/repos/collaborators/#list-collaborators
       # @example
       #   Octokit.collaborators('octokit/octokit.rb')
       # @example
@@ -286,24 +320,32 @@ module Octokit
       def collaborators(repo, options = {})
         paginate "#{Repository.path repo}/collaborators", options
       end
-      alias :collabs :collaborators
+      alias collabs collaborators
 
       # Add collaborator to repo
       #
+      # This can also be used to update the permission of an existing collaborator
+      #
       # Requires authenticated client.
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to add.
+      # @option options [String] :permission The permission to grant the collaborator.
+      #   Only valid on organization-owned repositories.
+      #   Can be one of: <tt>pull</tt>, <tt>push</tt>, or <tt>admin</tt>.
+      #   If not specified, defaults to <tt>push</tt>
       # @return [Boolean] True if collaborator added, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#add-collaborator
+      # @see https://developer.github.com/v3/repos/collaborators/#add-user-as-a-collaborator
       # @example
       #   @client.add_collaborator('octokit/octokit.rb', 'holman')
       # @example
       #   @client.add_collab('octokit/octokit.rb', 'holman')
+      # @example Add a collaborator with admin permissions
+      #   @client.add_collaborator('octokit/octokit.rb', 'holman', permission: 'admin')
       def add_collaborator(repo, collaborator, options = {})
         boolean_from_response :put, "#{Repository.path repo}/collaborators/#{collaborator}", options
       end
-      alias :add_collab :add_collaborator
+      alias add_collab add_collaborator
 
       # Remove collaborator from repo.
       #
@@ -312,7 +354,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to remove.
       # @return [Boolean] True if collaborator removed, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#remove-collaborator
+      # @see https://developer.github.com/v3/repos/collaborators/#remove-user-as-a-collaborator
       # @example
       #   @client.remove_collaborator('octokit/octokit.rb', 'holman')
       # @example
@@ -320,7 +362,7 @@ module Octokit
       def remove_collaborator(repo, collaborator, options = {})
         boolean_from_response :delete, "#{Repository.path repo}/collaborators/#{collaborator}", options
       end
-      alias :remove_collab :remove_collaborator
+      alias remove_collab remove_collaborator
 
       # Checks if a user is a collaborator for a repo.
       #
@@ -329,13 +371,25 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to check.
       # @return [Boolean] True if user is a collaborator, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#get
+      # @see https://developer.github.com/v3/repos/collaborators/#check-if-a-user-is-a-collaborator
       # @example
       #   @client.collaborator?('octokit/octokit.rb', 'holman')
-      def collaborator?(repo, collaborator, options={})
+      def collaborator?(repo, collaborator, options = {})
         boolean_from_response :get, "#{Repository.path repo}/collaborators/#{collaborator}", options
       end
 
+      # Get a user's permission level for a repo.
+      #
+      # Requires authenticated client
+      #
+      # @return [Sawyer::Resource] Hash representing the user's permission level for the given repository
+      # @see https://developer.github.com/v3/repos/collaborators/#review-a-users-permission-level
+      # @example
+      #   @client.permission_level('octokit/octokit.rb', 'lizzhale')
+      def permission_level(repo, collaborator, options = {})
+        get "#{Repository.path repo}/collaborators/#{collaborator}/permission", options
+      end
+
       # List teams for a repo
       #
       # Requires authenticated client that is an owner or collaborator of the repo.
@@ -352,8 +406,39 @@ module Octokit
       def repository_teams(repo, options = {})
         paginate "#{Repository.path repo}/teams", options
       end
-      alias :repo_teams :repository_teams
-      alias :teams :repository_teams
+      alias repo_teams repository_teams
+      alias teams repository_teams
+
+      # List all topics for a repository
+      #
+      # Requires authenticated client for private repos.
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @return [Sawyer::Resource] representing the topics for given repo
+      # @see https://developer.github.com/v3/repos/#list-all-topics-for-a-repository
+      # @example List topics for octokit/octokit.rb
+      #   Octokit.topics('octokit/octokit.rb')
+      # @example List topics for octokit/octokit.rb
+      #   client.topics('octokit/octokit.rb')
+      def topics(repo, options = {})
+        paginate "#{Repository.path repo}/topics", options
+      end
+
+      # Replace all topics for a repository
+      #
+      # Requires authenticated client.
+      #
+      # @param repo [Integer, String, Repository, Hash] A Github repository
+      # @param names [Array] An array of topics to add to the repository.
+      # @return [Sawyer::Resource] representing the replaced topics for given repo
+      # @see https://developer.github.com/v3/repos/#replace-all-topics-for-a-repository
+      # @example Replace topics for octokit/octokit.rb
+      #   client.replace_all_topics('octokit/octokit.rb', ['octocat', 'atom', 'electron', 'API'])
+      # @example Clear all topics for octokit/octokit.rb
+      #   client.replace_all_topics('octokit/octokit.rb', [])
+      def replace_all_topics(repo, names, options = {})
+        put "#{Repository.path repo}/topics", options.merge(names: names)
+      end
 
       # List contributors to a repo
       #
@@ -373,7 +458,7 @@ module Octokit
         options[:anon] = 1 if anon.to_s[/1|true/]
         paginate "#{Repository.path repo}/contributors", options
       end
-      alias :contribs :contributors
+      alias contribs contributors
 
       # List stargazers of a repo
       #
@@ -423,7 +508,7 @@ module Octokit
       def forks(repo, options = {})
         paginate "#{Repository.path repo}/forks", options
       end
-      alias :network :forks
+      alias network forks
 
       # List languages of code in the repo.
       #
@@ -481,7 +566,7 @@ module Octokit
       def branch(repo, branch, options = {})
         get "#{Repository.path repo}/branches/#{branch}", options
       end
-      alias :get_branch :branch
+      alias get_branch branch
 
       # Lock a single branch from a repository
       #
@@ -489,20 +574,39 @@ module Octokit
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param branch [String] Branch name
-      # @param required_status_checks [Hash]
+      # @option options [Hash] :required_status_checks If not null, the following keys are required:
+      #   <tt>:enforce_admins [boolean] Enforce required status checks for repository administrators.</tt>
+      #   <tt>:strict [boolean] Require branches to be up to date before merging.</tt>
+      #   <tt>:contexts [Array] The list of status checks to require in order to merge into this branch</tt>
+      #
+      # @option options [Hash] :restrictions If not null, the following keys are required:
+      #   <tt>:users [Array] The list of user logins with push access</tt>
+      #   <tt>:teams [Array] The list of team slugs with push access</tt>.
+      #
+      #   Teams and users restrictions are only available for organization-owned repositories.
       # @return [Sawyer::Resource] The protected branch
       # @see https://developer.github.com/v3/repos/#enabling-and-disabling-branch-protection
       # @example
       #   @client.protect_branch('octokit/octokit.rb', 'master', foo)
-      def protect_branch(repo, branch, required_status_checks = {}, options = {})
-        if !required_status_checks.empty?
-          required_status_checks = { :required_status_checks => required_status_checks }
-        end
+      def protect_branch(repo, branch, options = {})
+        options[:restrictions] ||= nil
+        options[:required_status_checks] ||= nil
+        put "#{Repository.path repo}/branches/#{branch}/protection", options
+      end
 
-        protection = { :protection => { :enabled => true }.merge(required_status_checks) }
-        options    = ensure_api_media_type(:branch_protection, options.merge(protection))
-
-        patch "#{Repository.path repo}/branches/#{branch}", options
+      # Get branch protection summary
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param branch [String] Branch name
+      # @return [Sawyer::Resource, nil] Branch protection summary or nil if the branch
+      #   is not protected
+      # @see https://developer.github.com/v3/repos/branches/#get-branch-protection
+      # @example
+      #   @client.branch_protection('octokit/octokit.rb', 'master')
+      def branch_protection(repo, branch, options = {})
+        get "#{Repository.path repo}/branches/#{branch}/protection", options
+      rescue Octokit::BranchNotProtected
+        nil
       end
 
       # Unlock a single branch from a repository
@@ -516,9 +620,25 @@ module Octokit
       # @example
       #   @client.unprotect_branch('octokit/octokit.rb', 'master')
       def unprotect_branch(repo, branch, options = {})
-        protection = { :protection => { :enabled => false } }
-        options = ensure_api_media_type(:branch_protection, options.merge(protection))
-        patch "#{Repository.path repo}/branches/#{branch}", options
+        boolean_from_response :delete, "#{Repository.path repo}/branches/#{branch}/protection", options
+      end
+
+      # Rename a single branch from a repository
+      #
+      # Requires authenticated client
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param branch [String] Current branch name
+      # @param new_name [String] New branch name
+      # @return [Sawyer::Resource] The renamed branch
+      # @see https://developer.github.com/v3/repos/#rename-a-branch
+      # @example
+      #   @client.rename_branch('octokit/octokit.rb', 'master', 'main')
+      def rename_branch(repo, branch, new_name, options = {})
+        params = {
+          new_name: new_name
+        }
+        post "#{Repository.path repo}/branches/#{branch}/rename", params.merge(options)
       end
 
       # List users available for assigning to issues.
@@ -537,7 +657,7 @@ module Octokit
       def repository_assignees(repo, options = {})
         paginate "#{Repository.path repo}/assignees", options
       end
-      alias :repo_assignees :repository_assignees
+      alias repo_assignees repository_assignees
 
       # Check to see if a particular user is an assignee for a repository.
       #
@@ -601,6 +721,59 @@ module Octokit
       def delete_subscription(repo, options = {})
         boolean_from_response :delete, "#{Repository.path repo}/subscription", options
       end
+
+      # Create a repository dispatch event
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param event_type [String] A custom webhook event name.
+      # @option options [Hash] :client_payload payload with extra information
+      #   about the webhook event that your action or worklow may use.
+      #
+      # @return [Boolean] True if event was dispatched, false otherwise.
+      # @see https://developer.github.com/v3/repos/#create-a-repository-dispatch-event
+      def dispatch_event(repo, event_type, options = {})
+        boolean_from_response :post, "#{Repository.path repo}/dispatches", options.merge({ event_type: event_type })
+      end
+
+      # Check to see if vulnerability alerts are enabled for a repository
+      #
+      # The authenticated user must have admin access to the repository.
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @return [Boolean] True if vulnerability alerts are enabled, false otherwise.
+      # @see https://docs.github.com/en/rest/reference/repos#check-if-vulnerability-alerts-are-enabled-for-a-repository
+      #
+      # @example
+      #   @client.vulnerability_alerts_enabled?("octokit/octokit.rb")
+      def vulnerability_alerts_enabled?(repo, options = {})
+        boolean_from_response(:get, "#{Repository.path repo}/vulnerability-alerts", options)
+      end
+
+      # Enable vulnerability alerts for a repository
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param options [Hash]
+      #
+      # @return [Boolean] True if vulnerability alerts enabled, false otherwise.
+      # @see https://docs.github.com/en/rest/reference/repos#enable-vulnerability-alerts
+      # @example Enable vulnerability alerts for a repository
+      #   @client.enable_vulnerability_alerts("octokit/octokit.rb")
+      def enable_vulnerability_alerts(repo, options = {})
+        boolean_from_response(:put, "#{Repository.path repo}/vulnerability-alerts", options)
+      end
+
+      # Disable vulnerability alerts for a repository
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @param options [Hash]
+      #
+      # @return [Boolean] True if vulnerability alerts disabled, false otherwise.
+      # @see https://docs.github.com/en/rest/reference/repos#disable-vulnerability-alerts
+      # @example Disable vulnerability alerts for a repository
+      #   @client.disable_vulnerability_alerts("octokit/octokit.rb")
+      def disable_vulnerability_alerts(repo, options = {})
+        boolean_from_response(:delete, "#{Repository.path repo}/vulnerability-alerts", options)
+      end
     end
   end
 end
